# Copyright 2013-2020 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack import *


class PyTvbMultiscale(PythonPackage):
    """
    Toolbox for Co-Simulation of TVB with NEST, NetPyNE and ANNarchy.
    """

    homepage = "https://github.com/the-virtual-brain/tvb-multiscale"
    # url = "https://github.com/the-virtual-brain/tvb-multiscale/archive/refs/tags/2.0.2.tar.gz"
    url = "https://github.com/the-virtual-brain/tvb-multiscale/archive/refs/tags/2.0.3.dev.tar.gz"

    maintainers = ['dionperd', 'paulapopa', "ldomide"]

    # version('2.0.2', sha256='647079e649225c7e9029bea9485872836a6dfe027a29718413e1e9e00255f4e6')
    version('2.0.3.dev', sha256='3763c709ccb554a4bb1a38350a8137e2287e4859ef5cd13ca744db3351ab0def')

    # python_requires
    depends_on('python@3.8:3.10', type=('build', 'run'))

    # setup_requires
    depends_on('py-pip', type='build')
    depends_on('py-setuptools', type='build')

    # install_requires
    depends_on('py-tvb-framework', type=('build', 'run'))
    depends_on('py-tvb-contrib', type=('build', 'run'))
    depends_on('nest', type=('build', 'run'))
    depends_on('py-netpyne', type=('build', 'run'))
    depends_on('py-annarchy', type=('build', 'run'))  # TODO!
    depends_on('py-nestml', type=('build', 'run'))
    depends_on('py-elephant', type=('build', 'run'))
    depends_on('py-pyspike', type=('build', 'run'))

    # Test dependency
    depends_on('py-pytest@:7.1', type='test')
    
    @run_after('install')
    @on_package_attributes(run_tests=True)
    def install_test(self):
        pytest = which('pytest')
        pytest('tvb_multiscale/tests')
